@@ -28,12 +28,6 @@
 
 #include <gtk/gtk.h>
 
-#ifdef HAVE_CLUTTER
-#include <cogl/cogl.h>
-#include <clutter/clutter.h>
-#include <clutter-gtk/clutter-gtk.h>
-#endif
-
 #ifdef HAVE_HILDON
 #include <libosso.h>
 
@@ -47,7 +41,6 @@
 #endif /* HAVE_HILDON */
 
 #include <libgames-support/games-debug.h>
-#include <libgames-support/games-files.h>
 #include <libgames-support/games-stock.h>
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-sound.h>
@@ -59,6 +52,7 @@
 #include "conf.h"
 #include "game.h"
 #include "window.h"
+#include "util.h"
 
 #if 0
 /* String reserve */
@@ -77,29 +71,6 @@ typedef struct {
 #endif /* HAVE_HILDON */
 } AppData;
 
-static char *
-variation_to_game_file (const char *variation)
-{
-  char *game_file, *s;
-
-  game_file = g_ascii_strdown (variation, -1);
-
-  /* Replace dangerous characters: '.' (as in "..") and '/' */
-  g_strdelimit (game_file, "." G_DIR_SEPARATOR_S, '\0');
-  g_strdelimit (game_file, NULL, '_');
-
-  if (game_file[0] == '\0') {
-    g_free (game_file);
-    return NULL;
-  }
-
-  /* Add the suffix */
-  s = g_strconcat (game_file, ".scm", NULL);
-  g_free (game_file);
-
-  return s;
-}
-
 #ifdef WITH_SMCLIENT
 
 static void
@@ -290,10 +261,6 @@ main_prog (void *closure, int argc, char *argv[])
 #ifdef WITH_SMCLIENT
   g_option_context_add_group (option_context, egg_sm_client_get_option_group ());
 #endif /* WITH_SMCLIENT */
-#ifdef HAVE_CLUTTER
-  g_option_context_add_group (option_context, cogl_get_option_group ());
-  g_option_context_add_group (option_context, clutter_get_option_group_without_init ());
-#endif
 
 #if defined(HAVE_HILDON) && defined(HAVE_MAEMO_5)
   {
@@ -318,14 +285,6 @@ main_prog (void *closure, int argc, char *argv[])
     goto cleanup;
   }
 
-#ifdef HAVE_CLUTTER
-  if (gtk_clutter_init_with_args (NULL, NULL, NULL, NULL, NULL, &error) != CLUTTER_INIT_SUCCESS) {
-    g_printerr ("Failed to initialise clutter: %s\n", error->message);
-    g_error_free (error);
-    goto cleanup;
-  }
-#endif
-
 #ifdef HAVE_MAEMO
   data.program = HILDON_PROGRAM (hildon_program_get_instance ());
 
@@ -343,7 +302,7 @@ main_prog (void *closure, int argc, char *argv[])
     char *game_file = NULL;
 
     if (data.variation[0] != '\0') {
-      game_file = variation_to_game_file (data.variation);
+      game_file = aisleriot_variation_to_game_file (data.variation);
     }
 
     g_free (data.variation);
@@ -431,6 +390,10 @@ cleanup:
   }
 #endif /* HAVE_MAEMO */
 
+#if GLIB_CHECK_VERSION (2, 25, 15)
+  g_settings_sync ();
+#endif
+
   games_runtime_shutdown ();
 }
 
